@@ -3,22 +3,25 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory.
 
-__version__ = '1.2.0'
+__version__ = '1.3.9'
 
 __all__ = [
     'cmaes',
     'cmaescpp',
+    'de',
     'dacpp',
     'decpp',
     'gcldecpp',
     'ldecpp',
     'lgcldecpp',
-    'hhcpp',
     'bitecpp',
     'csmacpp',
     'retry',
     'advretry',
     'multiretry',
+    'mode',
+    'modecpp',
+    'moretry',
     'pygmoretry',
     'optimizer',
     'astro',
